Glossary
========

Audio Module
------------

Observation Duration
  The length of the audio(s), in seconds.

Sampling Rate:
  The sample rate of the audio(s), in Hertz.

Voice Classification:
  The detected sounds in the audio(s).

Energy RMS
  RMS level (root mean squared) of the audio(s) is proportional to the amount of energy over a period of time in the signal.
  This can be used to distinguish audios that are louder from each other.


Video Module
------------

Duration
  The length of the video(s), in seconds.

Resolution
  The resolution of the video(s), in pixels.

Format
  The format of the video(s).

Bitrate
  The bit rate of the video(s), in bits.

Framerate
  The frame rate of the video(s), in frames.

Illumination(Brightness)
  The brightness of the video(s), in luminance.

Creation Date
  The creation date of the video(s), it is the creation date of the media instead of the actual file. 
  If this part is missing in the metadata, the module will return N/A.

Artifacts Ratio
  The ratio of distorted frames in the video by the total number of frames.

Sensor Module
-------------

DQM
  Data Quality Matrix. The matrix generated by the pipeline, including all the quality assessment metrics
  that are related to user's research.

Correctness
  One of the three aspects that the pipeline evaluates. It measures the overall correctness of the input data
  via APD and SNR.

Completeness
  One of the three aspects that the pipeline evaluates. It measures the overall completeness of the input data
  via IRLR, MDR, SCR, and VDR.

Consistency
  One of the three aspects that the pipeline evaluates. It measures the overall consistency of the input data
  via RLC, SRC, and VRC.

APD
  Anomalous Points Density. The ratio of the number of outliers/anomalous data samples over the total number of samples.

IRLR
  Interpretable Record Length Ratio. The ratio of the number of interpretable records over the total number of records.
  A record is interpretable if it satisfies the following: 
  a. Has more than one row of data. 
  b. Has non-decreasing timestamp.
  c. Has non-zero standard deviation on each data channel.

MDR
  Missing Data Ratio. The ratio of the number of missing data samples over the total number of samples. 
  The MDR metric measures the level of discontinuity manifested through skipped data points due to undersampling.

RLC
  Record Length Consistency. The uniformness of data record length across multiple records.

SCR
  Sensor Channel Ratio. The ratio of the number of records that has full channels over the total number of records.
  A record is defined to have full channels if the number of its channels is the same as the mode of the number of channels
  of given input. 

SNR
  Signal-to-noise Ratio. The ratio of desired signal amplitude over the noise amplitude.
  This metric gives insight into the noise level rather than its type, providing feedback on the required level of data denoising. 

SRC
  Sampling Rate Consistency. The uniformness of the data sampling rate within a record.

VRC
  Value Range Consistency. The uniformness of the value range across multiple records.

VDR
  Valid Data Ratio. The ratio of the number of non-NaN data points over the total number of data points. 